################ Script MANOVA ################

# This is a script accompanying the manuscript
# "Responses of macroalgae to CO2 enrichment cannot be inferred solely from their inorganic carbon uptake strategy"
# Published in Ecology & Evolution


##### load and organise data #####
library(xlsx)
library(ggplot2)

d <- read.table("Data_MANOVA.txt",header=TRUE)

str(d)

##### MANOVA #####
# possible tests = c("Pillai", "Wilks", "Hotelling-Lawley", "Roy")

# biological parameters
res.man <- manova(cbind(linear, weight, chla, phyco, photo, dd13C, CN, Ccontent, Ncontent, lipidcontent, FAcontent) 
                  ~ species * treatment, data = d)
summary(res.man,test="Pillai")
summary.aov(res.man)


# carbonate parameters
res.man <- manova(cbind(dH, dDIC, dHCO3, dCO3) 
                  ~ species * treatment, data = d)
summary(res.man,test="Pillai")
summary.aov(res.man)

res.man <- manova(cbind(dH, dDIC, dHCO3, dCO2) 
                  ~ species * treatment, data = d)
summary(res.man,test="Pillai")
summary.aov(res.man)


##### check the underlying assumptions #####
# first we need to make vectors of the two predictor variables
species <- as.factor(d[,2])
treatment <- as.factor(d[,3])

# and for some analyses we need to remove the NA values:
data_NAomit <- na.omit(d)
species2 <- as.factor(data_NAomit[,2])
treatment2 <- as.factor(data_NAomit[,2])


###### check normality #####
# test species
# first we need to create residuals:
LinResSpec=lm(d$linear~species)$residuals
WeiResSpec=lm(d$weight~species)$residuals
ChlResSpec=lm(d$chla~species)$residuals
PhyResSpec=lm(d$phyco~species)$residuals
PhotoResSpec=lm(d$photo~d$species)$residuals
dd13cResSpec=lm(d$dd13C~d$species)$residuals
CNResSpec=lm(d$CN~species)$residuals
CconResSpec=lm(d$Ccontent~species)$residuals
NconResSpec=lm(d$Ncontent~species)$residuals
LipResSpec=lm(d$lipidcontent~species)$residuals
FAResSpec=lm(d$FAcontent~species)$residuals
dHResSpec=lm(d$dH~species)$residuals
DICResSpec=lm(d$dDIC~species)$residuals
HCOResSpec=lm(d$dHCO3~species)$residuals
CO3ResSpec=lm(d$dCO3~species)$residuals
CO2ResSpec=lm(d$dCO2~species)$residuals

# then do shapiro tests or use visual inspection:
shapiro.test(LinResSpec) # not
boxplot(lm(d$linear~species)$residuals~species) # graphic check looks OK
shapiro.test(WeiResSpec) # OK
shapiro.test(ChlResSpec) # OK
shapiro.test(PhyResSpec) # not, but the graphic check:
boxplot(lm(d$phyco~species)$residuals~species) # also looks pretty good
shapiro.test(PhotoResSpec) # OK
shapiro.test(dd13cResSpec) # OK
shapiro.test(CNResSpec) # OK
shapiro.test(CconResSpec) # OK
shapiro.test(NconResSpec) # OK
shapiro.test(LipResSpec) # not, but the graphic check:
boxplot(lm(d$lipidcontent~species)$residuals~species) # looks fine
shapiro.test(FAResSpec) # OK
shapiro.test(dHResSpec) # not, graphic check:
boxplot(lm(data_NAomit$dH~species2)$residuals~species2) # looks fine
shapiro.test(DICResSpec) # OK
shapiro.test(HCOResSpec) # OK
shapiro.test(CO3ResSpec) # OK
shapiro.test(CO2ResSpec) # not, graphic check:
boxplot(lm(data_NAomit$dCO2~species2)$residuals~species2) # looks fine

# test Treatment (again, first create residuals and then do tests)
LinResTreat=lm(d$linear~treatment)$residuals
WeiResTreat=lm(d$weight~treatment)$residuals
ChlResTreat=lm(d$chla~treatment)$residuals
PhyResTreat=lm(d$phyco~treatment)$residuals
PhotoResTreat=lm(d$photo~d$treatment)$residuals
dd13cResTreat=lm(d$dd13C~d$treatment)$residuals
CNResTreat=lm(d$CN~treatment)$residuals
CconResTreat=lm(d$Ccontent~treatment)$residuals
NconResTreat=lm(d$Ncontent~treatment)$residuals
LipResTreat=lm(d$lipidcontent~treatment)$residuals
FAResTreat=lm(d$FAcontent~treatment)$residuals
dHResTreat=lm(d$dH~treatment)$residuals
DICResTreat=lm(d$dDIC~treatment)$residuals
HCOResTreat=lm(d$dHCO3~treatment)$residuals
CO3ResTreat=lm(d$dCO3~treatment)$residuals
CO2ResTreat=lm(d$dCO2~treatment)$residuals

shapiro.test(LinResTreat) # not, but (same as for species), we can use the graphic check:
boxplot(lm(d$linear~treatment)$residuals~treatment) # one outlier, but fine otherwise 
shapiro.test(WeiResTreat) # OK
shapiro.test(ChlResTreat) # OK
shapiro.test(PhyResTreat) # not
shapiro.test(PhotoResTreat) # OK
shapiro.test(dd13cResTreat) # OK
shapiro.test(CNResTreat) # OK
shapiro.test(CconResTreat) # not (p=0.04755)
boxplot(lm(data_NAomit$Ccontent~treatment2)$residuals~treatment2) # OK
shapiro.test(NconResTreat) # OK
shapiro.test(LipResTreat) # OK
shapiro.test(FAResTreat) # OK
shapiro.test(dHResTreat) # not, but:
boxplot(lm(data_NAomit$dH~treatment2)$residuals~treatment2) # looks good
shapiro.test(DICResTreat) # OK
shapiro.test(HCOResTreat) # OK
shapiro.test(CO3ResTreat) # OK
shapiro.test(CO2ResTreat) # not, but:
boxplot(lm(data_NAomit$dCO2~treatment2)$residuals~treatment2) # looks good


###### check for homogeinity #####
# the residuals have been created during the normality check. We use these again, but now do levene's tests:
library(car)

leveneTest(LinResSpec~species) # OK
leveneTest((WeiResSpec=lm(data_NAomit$weight~species2))$residuals ~species2) # OK
leveneTest(ChlResSpec~species) # OK
leveneTest(PhyResSpec~species) # OK
leveneTest(PhotoResSpec~species) # OK
leveneTest((dd13cResSpec=lm(data_NAomit$dd13C~species2))$residuals ~species2) # OK
leveneTest((CNResSpec=lm(data_NAomit$CN~species2))$residuals ~species2) # OK
leveneTest((CconResSpec=lm(data_NAomit$Ccontent~species2))$residuals ~species2) # OK
leveneTest((NconResSpec=lm(data_NAomit$Ncontent~species2))$residuals ~species2) # OK
leveneTest(LipResSpec~species) # OK
leveneTest(FAResSpec~species) # OK
leveneTest((dHResSpec=lm(data_NAomit$dH~species2))$residuals ~species2) # OK
leveneTest((DICResSpec=lm(data_NAomit$dDIC~species2))$residuals ~species2) # OK
leveneTest((HCOResSpec=lm(data_NAomit$dHCO3~species2))$residuals ~species2) # OK
leveneTest((CO3ResSpec=lm(data_NAomit$dCO3~species2))$residuals ~species2) # OK
leveneTest((CO2ResSpec=lm(data_NAomit$dCO2~species2))$residuals ~species2) # OK

leveneTest(LinResTreat~treatment) # barely OK
leveneTest((WeiResTreat=lm(data_NAomit$weight~treatment2))$residuals ~treatment2) # OK
leveneTest(ChlResTreat~treatment) # OK
leveneTest(PhyResTreat~treatment) # OK
leveneTest(PhotoResTreat~treatment) # OK
leveneTest((dd13cResTreat=lm(data_NAomit$dd13C~treatment2))$residuals ~treatment2) # OK
leveneTest((CNResTreat=lm(data_NAomit$CN~treatment2))$residuals ~treatment2) # OK
leveneTest((CconResTreat=lm(data_NAomit$Ccontent~treatment2))$residuals ~treatment2) # OK
leveneTest((NconResTreat=lm(data_NAomit$Ncontent~treatment2))$residuals ~treatment2) # OK
leveneTest(LipResTreat~treatment) # OK
leveneTest(FAResTreat~treatment) # OK
leveneTest((dHResTreat=lm(data_NAomit$dH~treatment2))$residuals ~treatment2) # OK
leveneTest((DICResTreat=lm(data_NAomit$dDIC~treatment2))$residuals ~treatment2) # OK
leveneTest((HCOResTreat=lm(data_NAomit$dHCO3~treatment2))$residuals ~treatment2) # OK
leveneTest((CO3ResTreat=lm(data_NAomit$dCO3~treatment2))$residuals ~treatment2) # OK
leveneTest((CO2ResTreat=lm(data_NAomit$dCO2~treatment2))$residuals ~treatment2) # OK

################ End of script ################